@@ -14,11 +14,11 @@ Git::Repository::Plugin::Blame::Cache - Cache the output of C<< Git::Repository-
 
 =head1 VERSION
 
-Version 1.2.3
+Version 1.3.0
 
 =cut
 
-our $VERSION = '1.2.3';
+our $VERSION = '1.3.0';
 
 my $CACHE = {};
 
@@ -60,17 +60,24 @@ Return a cache object for the specified repository.
 
 	my $cache = Git::Repository::Plugin::Blame::Cache->new(
 		repository => $repository,
+		options    => $options,
 	);
 
 Arguments:
 
 =over 4
 
-=item * repository (mandatory)
+=item * repository I<(mandatory)>
 
 A unique way to identify a repository. Typically, the root path of the
 repository.
 
+=item * blame_args I<(optional)>
+
+A hashref of arguments used to generate the C<git blame> output, if applicable.
+This avoids caching the same output for C<git blame> and C<git blame -w>, for
+example.
+
 =back
 
 =cut
@@ -79,24 +86,45 @@ sub new
 {
 	my ( $class, %args ) = @_;
 	my $repository = delete( $args{'repository'} );
+	my $blame_args = delete( $args{'blame_args'} ) || {};
 	croak 'The following arguments are not valid: ' . join( ',', keys %args )
 		if scalar( keys %args ) != 0;
 
+	# Verify mandatory arguments.
 	croak 'The "repository" argument is mandatory'
 		if !defined( $repository ) || $repository eq '';
 
-	if ( !defined( $CACHE->{ $repository } ) )
+	# Serialize the options passed, to hold a separate cache entry for each set
+	# of options.
+	my $serialized_blame_args = '';
+	if ( scalar( keys %$blame_args ) != 0 )
 	{
-		$CACHE->{ $repository } = bless(
+		my @blame_args = ();
+		foreach my $blame_arg ( sort keys %$blame_args )
+		{
+			my $value = defined( $blame_args->{ $blame_arg } )
+				? $blame_args->{ $blame_arg }
+				: '';
+			push( @blame_args, "$blame_arg=$value" );
+		}
+		$serialized_blame_args = join( ',', @blame_args );
+	}
+
+	# If the cache element does not exist, create it.
+	if ( !defined( $CACHE->{ $repository }->{ $serialized_blame_args } ) )
+	{
+		$CACHE->{ $repository }->{ $serialized_blame_args } = bless(
 			{
-				repository => $repository,
-				files      => {},
+				repository            => $repository,
+				files                 => {},
+				serialized_blame_args => $serialized_blame_args,
 			},
 			$class,
 		);
 	}
 
-	return $CACHE->{ $repository };
+	# Return the corresponding cache element.
+	return $CACHE->{ $repository }->{ $serialized_blame_args };
 }
 
 
@@ -242,7 +270,7 @@ C<< <aubertg at cpan.org> >>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012-2014 Guillaume Aubert.
+Copyright 2012-2015 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
